==> serendipity_1.2.1.orig.tar.gz: serendipity/templates/bulletproof/lang_bg.inc.php <==
<?php

/* $Id: lang_bg.inc.php 2053 2007-12-04 11:29:35Z yellowled $
Translator: Ivan Cenov (jwalker@hotmail.bg)
*/

// Colorsets
@define('THEME_COLORSET', ' ');
@define('USER_STYLESHEET','');
// Layout
@define('LAYOUT_TYPE','  (B = , S =  , CF =  )');
@define('LAYOUT_SBS','  S-B-S');
@define('LAYOUT_BSS',' , B-S-S, CF');
@define('LAYOUT_SSB',' , S-S-B');
@define('LAYOUT_SB',' , S-B');
@define('LAYOUT_BS',' , B-S, CF');
@define('LAYOUT_SC',' ,  , CF');
@define('JAVASCRIPT_COLUMNS','      (  Javascript,         ');
// Custom header
@define('BP_CUSTOM_HEADER','         ');
@define('BP_HEADER_IMAGE','  ');
@define('BP_HEADER_TYPE','  ');
@define('BP_HEADER_BANNER', ' ( )');
@define('BP_HEADER_HTILED', ' ');
@define('BP_HEADER_VTILED', ' ');
@define('BP_HEADER_BTILED', '   ');
@define('BP_HEADER_POSHOR', ' ');
@define('BP_HEADER_POSVER', ' ');
@define('BP_CENTER', '');
@define('BP_TOP', '');
@define('BP_BOTTOM', '');
// Fahrner Image Replacement
@define('FIR_BTITLE','      ');
@define('FIR_BDESCR','      ');
// Date format
@define('BP_DATE_FORMAT', '  ');
// Entry footer
@define('ENTRY_FOOTER_POS','    ');
@define('BELOW_ENTRY',' ');
@define('BELOW_TITLE','   ');
@define('SPLIT_FOOTER',' ');
@define('FOOTER_AUTHOR','      ');
@define('FOOTER_CATEGORIES','      ');
@define('FOOTER_TIMESTAMP','  /    ');
@define('FOOTER_COMMENTS','        ');
@define('FOOTER_TRACKBACKS','        ');
@define('ALT_COMMTRACK','          ( " "  "1 "  " (0)"  " (1)")');
@define('SHOW_ADDTHIS_WIDGET','    AddThis (http://www.addthis.com)    ');
@define('ADDTHIS_ACCOUNT','   AddThis.com.   ,                 .');
@define('SHOW_STICKY_ENTRY_FOOTER','      (  "   " ("Extended properties for entries"))');
@define('SHOW_STICKY_ENTRY_HEADING','      (  "   " ("Extended properties for entries"))');
// Page footer next page  and previous page links
@define('PREV_NEXT_STYLE','    /      ');
@define('PREV_NEXT_TEXT',' ');
@define('PREV_NEXT_TEXT_ICON','  ');
@define('PREV_NEXT_ICON',' ');
// coComment support
@define('COCOMMENT_ACTIVE','  coComment (http://www.cocomment.com)    ');
// Counter code
@define('COUNTER_CODE', '  WEB  / ');
@define('USE_COUNTER', '  ,    ');
// Additional footer text
@define('FOOTER_TEXT', '     ');
@define('USE_FOOTER_TEXT', '   ,    ');
//Sitenav
@define('SITENAV_POSITION','   ');
@define('SITENAV_NONE','');
@define('SITENAV_ABOVE',' ');
@define('SITENAV_BELOW',' ');
@define('SITENAV_LEFT','   ');
@define('SITENAV_RIGHT','   ');
@define('SITENAV_FOOTER','      (    ,      )');
@define('SITENAV_QUICKSEARCH','         (,         ;             )');
@define('SITENAV_TITLE','    (        )');
@define('SITENAV_TITLE_TEXT',' ');
@define('NAVLINK_AMOUNT', '      (     "   -       )');
@define('NAV_LINK_TEXT', '  ');
@define('NAV_LINK_URL', ' URL  ');

==> serendipity_1.3.1.orig.tar.gz: serendipity/templates/bulletproof/lang_bg.inc.php <==
<?php

/* $Id: lang_bg.inc.php 2128 2008-02-18 13:54:09Z jwalker $
Translator: Ivan Cenov (jwalker@hotmail.bg)
*/

// Colorsets
@define('THEME_COLORSET', ' ');
@define('USER_STYLESHEET','   CSS.          (bulletproof)      user.css.        .');
// Layout
@define('LAYOUT_TYPE','  (B = , S =  , CF =  )');
@define('LAYOUT_SBS','  S-B-S');
@define('LAYOUT_BSS',' , B-S-S, CF');
@define('LAYOUT_SSB',' , S-S-B');
@define('LAYOUT_SB',' , S-B');
@define('LAYOUT_BS',' , B-S, CF');
@define('LAYOUT_SC',' ,  , CF');
@define('LAYOUT_SBF',' , S-B + ');
@define('LAYOUT_BSF',' , S-R + , CF');
@define('JAVASCRIPT_COLUMNS','      (  Javascript,         )');
// Custom header
@define('BP_CUSTOM_HEADER','         ');
@define('BP_HEADER_IMAGE','  ');
@define('BP_HEADER_TYPE','  ');
@define('BP_HEADER_BANNER', ' ( )');
@define('BP_HEADER_HTILED', ' ');
@define('BP_HEADER_VTILED', ' ');
@define('BP_HEADER_BTILED', '   ');
@define('BP_HEADER_POSHOR', ' ');
@define('BP_HEADER_POSVER', ' ');
@define('BP_CENTER', '');
@define('BP_TOP', '');
@define('BP_BOTTOM', '');
// Fahrner Image Replacement
@define('FIR_BTITLE','      ');
@define('FIR_BDESCR','      ');
// Date format
@define('BP_DATE_FORMAT', '  ');
// Entry footer
@define('ENTRY_FOOTER_POS','    ');
@define('BELOW_ENTRY',' ');
@define('BELOW_TITLE','   ');
@define('SPLIT_FOOTER',' ');
@define('FOOTER_AUTHOR','      ');
@define('FOOTER_CATEGORIES','      ');
@define('FOOTER_TIMESTAMP','  /    ');
@define('FOOTER_COMMENTS','        ');
@define('FOOTER_TRACKBACKS','        ');
@define('ALT_COMMTRACK','          ( " "  "1 "  " (0)"  " (1)")');
@define('SHOW_ADDTHIS_WIDGET','    AddThis (http://www.addthis.com)    ');
@define('ADDTHIS_ACCOUNT','   AddThis.com.   ,                 .');
@define('SHOW_STICKY_ENTRY_FOOTER','      (  "   " ("Extended properties for entries"))');
@define('SHOW_STICKY_ENTRY_HEADING','      (  "   " ("Extended properties for entries"))');
// Page footer next page  and previous page links
@define('PREV_NEXT_STYLE','    /      ');
@define('PREV_NEXT_TEXT',' ');
@define('PREV_NEXT_TEXT_ICON','  ');
@define('PREV_NEXT_ICON',' ');
// coComment support
@define('COCOMMENT_ACTIVE','  coComment (http://www.cocomment.com)    ');
// Counter code
@define('COUNTER_CODE', '  WEB  / ');
@define('USE_COUNTER', '  ,    ');
// Additional footer text
@define('FOOTER_TEXT', '     ');
@define('USE_FOOTER_TEXT', '   ,    ');
//Sitenav
@define('SITENAV_POSITION','   ');
@define('SITENAV_NONE','');
@define('SITENAV_ABOVE',' ');
@define('SITENAV_BELOW',' ');
@define('SITENAV_LEFT','   ');
@define('SITENAV_RIGHT','   ');
@define('SITENAV_FOOTER','      (    ,      )');
@define('SITENAV_QUICKSEARCH','         (,         ;             )');
@define('SITENAV_TITLE','    (        )');
@define('SITENAV_TITLE_TEXT',' ');
@define('NAVLINK_AMOUNT', '      (     "   -       )');
@define('NAV_LINK_TEXT', '  ');
@define('NAV_LINK_URL', ' URL  ');
